@@ -1,10 +1,10 @@
 #[macro_export] macro_rules!
 show {
-    ($($arg:tt),*) => {
+    ($($arg:expr),*) => {
         $(print!("{} ", $arg);)*
         println!("");
     };
-    ($($arg:tt),*; $($a:tt)*) => {
+    ($($arg:expr),*; $($a:tt)*) => {
         $(print!("{} ", $arg);)*
         println!("");
     };
