@@ -19,3 +19,5 @@ pub type Handle<T> = std::io::Result<T>;
 pub type Maybe<T> = Option<T>;
 
 pub type text = &'static str;
+use std::io::*;
+fn ERROR<T>(a: &'static str) -> std::io::Result<T> { Err(Error::new(ErrorKind::Other, a)) }
